class SingleSourceError(Exception):
    """Base exception for the library"""


class VersionNotFoundError(SingleSourceError):
    """
    Raise when the version of a package has not been found
    neither in package metadata nor in a file
    """



import re
from pathlib import Path
from typing import Optional, Union

from .errors import VersionNotFoundError

try:
    import importlib.metadata as importlib_metadata
except ModuleNotFoundError:
    # for Python <3.8 add 'importlib_metadata' as a dependency
    import importlib_metadata  # type: ignore


VERSION_REGEX = r"\s*version\s*=\s*[\"']\s*([-.\w]{3,})\s*[\"']\s*"


def get_version(
    package_name: str,
    target_dir_or_file: Union[Path, str],
    *,
    fail: bool = False,
    default_return: Optional[str] = "",
    version_regex: str = VERSION_REGEX,
) -> Optional[str]:
    """
        Retrieve your project version from package metadata or file with regex
        (by default from "pyproject.toml")

        :param package_name: The name of your package
        :type package_name: str
        :param target_dir_or_file: A path to a file or to a directory
    which contains pyproject.toml
        :type target_dir_or_file: Union[Path, str]
        :param fail: Raises VersionNotFoundError if True, by default False
        :type fail: bool
        :param default_return: Returns when the version hasn't been found,
        empty string by default, ignored when fail is True
        :type default_return: Optional[str]
        :param version_regex: Regular expression for parsing version from a file
        :type version_regex: str

        :raises: VersionNotFoundError
        :return: Version of the package, returns "default_return" value
        if version cannot be parsed
        :rtype: Optional[str]
    """
    if isinstance(target_dir_or_file, (Path, str)):
        target_path = Path(target_dir_or_file)
    else:
        raise TypeError(
            f"'target_dir_or_file' argument can be 'str' or "
            f"'pathlib.Path' type, got {type(target_dir_or_file)}"
        )

    pyproject_name = "pyproject.toml"
    if not target_path.is_file():
        target_path /= pyproject_name

    version: Optional[str]
    version = _get_version_from_metadata(package_name)
    if version is None:
        version = _get_version_from_path(target_path, version_regex)

    if not version and fail:
        raise VersionNotFoundError(
            f"You either have to install '{package_name}' package "
            f"or {target_path} must contain 'version' in [tool.poetry]"
        )
    return version or default_return


def _get_version_from_metadata(package_name: str) -> Optional[str]:
    """Implements a getting version flow for installed package"""
    try:
        version = importlib_metadata.version(package_name)
    except importlib_metadata.PackageNotFoundError:
        return None
    else:
        return version.strip()


def _get_version_from_path(file_path: Path, version_regex: str) -> Optional[str]:
    """
    Implements a getting version from file flow for developers,
    without installed package
    """
    compiled_version_regex = re.compile(version_regex)
    try:
        with file_path.open(mode="r", encoding="utf-8") as file_with_version:
            for line in file_with_version:
                version: re.Match = compiled_version_regex.search(line)  # type: ignore
                if version is not None:
                    return version.group(1).strip()
    except (FileNotFoundError, UnicodeDecodeError):
        return None

    return None



__all__ = (
    "__version__",
    "get_version",
    "SingleSourceError",
    "VersionNotFoundError",
)

from pathlib import Path

from .errors import SingleSourceError, VersionNotFoundError
from .version import get_version

__version__ = get_version(__name__, Path(__file__).parent.parent)



import json
from datetime import datetime

import requests
import typer
from rich.console import Console
from rich.syntax import Syntax
from rich.traceback import install

from .config import api_key, api_url

# Initiate Rich traceback handlers
install()

app = typer.Typer()
console = Console()
error_console = Console(stderr=True, style="bold red")

now = datetime.now().replace(microsecond=0).isoformat()


def process_query(index, query, start, end, raw, metadata):
    start = start.replace(microsecond=0).isoformat()
    end = end.replace(microsecond=0).isoformat()
    results = None

    if index == "DNS":
        query_string = (
            f"host.raw:{query} AND collection_timestamp:[{start} TO {end}]&index=dns"
        )
    else:
        query_string = f"data.leaf_cert.all_domains:{query} AND collection_timestamp:[{start} TO {end}]&index=certstream"

    with console.status(f"[bold green]Searching Cetus {index} index..."):
        results = requests.get(
            f"{api_url}/api/query?q={query_string}",
            headers={"Authorization": f"Token {api_key}"},
        )
        try:
            # Validates JSON response and convert to Python dict
            data = json.loads(results.text)
        except ValueError:
            error_console.print("Error: Response did not include valid JSON")
            error_console.print_exception()
            return

    if not metadata:
        data = data["data"]["es_response"]
        if not data:
            if not raw:
                console.print(":pile_of_poo: No results found.")
            else:
                print(json.dumps(data))
            return

    formatted_data = Syntax(json.dumps(data, indent=4), "json")
    console.print(formatted_data) if not raw else print(json.dumps(data))


@app.command()
def dns(
    query: str = typer.Argument(..., help="Lucene formatted query."),
    start: datetime = typer.Option(..., help="Beginning of search range. Required."),
    end: datetime = typer.Option(
        str(now), help="End of search range. If omitted, end == now"
    ),
    raw: bool = typer.Option(
        False, "--raw", help="Print raw output instead of pretty printed"
    ),
    metadata: bool = typer.Option(
        False, "--metadata", help="Include metadata in output"
    ),
):
    """
    Search the Cetus DNS index
    """
    process_query("DNS", query, start, end, raw, metadata)


@app.command()
def certstream(
    query: str = typer.Argument(..., help="Lucene formatted query."),
    start: datetime = typer.Option(..., help="Beginning of search range. Required."),
    end: datetime = typer.Option(
        str(now), help="End of search range. If omitted, end == now"
    ),
    raw: bool = typer.Option(
        False, "--raw", help="Print raw output instead of pretty printed"
    ),
    metadata: bool = typer.Option(
        False, "--metadata", help="Include metadata in output"
    ),
):
    """
    Search the Cetus Certstream index
    """
    process_query("Certstream", query, start, end, raw, metadata)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['cetus_cearcher', 'cetus_cearcher.third_party.singlesource']

package_data = \
{'': ['*'], 'cetus_cearcher': ['examples/*']}

install_requires = \
['requests>=2.25.1,<3.0.0',
 'rich>=10.3.0,<11.0.0',
 'typer-cli>=0.0.11,<0.0.12',
 'typer>=0.3.2,<0.4.0']

entry_points = \
{'console_scripts': ['cetus = cetus_cearcher.main:app']}

setup_kwargs = {
    'name': 'cetus-cearcher',
    'version': '0.1.1',
    'description': 'Client for the Cetus API',
    'long_description': "# `Cetus Cearcher`\n\nUnofficial CLI tool to query the Cetus API maintained by SparkIT Solutions.\n\n## Installation\n\nClone the repo and use [Typer CLI](https://typer.tiangolo.com/typer-cli/) to run\n\nor\n\n`pip install cetus-cearcher`\n\n\nOnce installed, you'll need to create a file named `config.py` in the `cetus` directory and declare two variables:\n\n|Variable |Value|\n|---|---|\n|api_url|API server including protocol ( i.e. `https://example.com` )|\n|api_key|API key obtained from the portal|\n\n## Usage\n\n```console\n$ cetus [OPTIONS] COMMAND [ARGS]...\n```\n\n**Options**:\n\n* `--install-completion`: Install completion for the current shell.\n* `--show-completion`: Show completion for the current shell, to copy it or customize the installation.\n* `--help`: Show this message and exit.\n\n**Commands**:\n\n* `example`: Show example result data\n* `search`: Search Cetus\n\n## `cetus example`\n\nShow example result data\n\n**Usage**:\n\n```console\n$ cetus example [OPTIONS] INDEX:[dns|certstream]\n```\n\n**Arguments**:\n\n* `INDEX:[dns|certstream]`: [required]\n\n**Options**:\n\n* `--raw`: Print raw output instead of pretty printed  [default: False]\n* `--help`: Show this message and exit.\n\n## `cetus search`\n\nSearch Cetus\n\n**Usage**:\n\n```console\n$ cetus search [OPTIONS] COMMAND [ARGS]...\n```\n\n**Options**:\n\n* `--help`: Show this message and exit.\n\n**Commands**:\n\n* `certstream`: Search the Cetus Certstream index\n* `dns`: Search the Cetus DNS index\n\n### `cetus search certstream`\n\nSearch the Cetus Certstream index\n\n**Usage**:\n\n```console\n$ cetus search certstream [OPTIONS] QUERY\n```\n\n**Arguments**:\n\n* `QUERY`: Lucene formatted query.  [required]\n\n**Options**:\n\n* `--start [%Y-%m-%d|%Y-%m-%dT%H:%M:%S|%Y-%m-%d %H:%M:%S]`: Beginning of search range. Required.  [required]\n* `--end [%Y-%m-%d|%Y-%m-%dT%H:%M:%S|%Y-%m-%d %H:%M:%S]`: End of search range. If omitted, end == now  [default: 2021-06-10T17:11:20]\n* `--raw`: Print raw output instead of pretty printed  [default: False]\n* `--metadata`: Include metadata in output  [default: False]\n* `--help`: Show this message and exit.\n\n### `cetus search dns`\n\nSearch the Cetus DNS index\n\n**Usage**:\n\n```console\n$ cetus search dns [OPTIONS] QUERY\n```\n\n**Arguments**:\n\n* `QUERY`: Lucene formatted query.  [required]\n\n**Options**:\n\n* `--start [%Y-%m-%d|%Y-%m-%dT%H:%M:%S|%Y-%m-%d %H:%M:%S]`: Beginning of search range. Required.  [required]\n* `--end [%Y-%m-%d|%Y-%m-%dT%H:%M:%S|%Y-%m-%d %H:%M:%S]`: End of search range. If omitted, end == now  [default: 2021-06-10T17:11:20]\n* `--raw`: Print raw output instead of pretty printed  [default: False]\n* `--metadata`: Include metadata in output  [default: False]\n* `--help`: Show this message and exit.\n",
    'author': 'Kory Kyzar',
    'author_email': 'k2@korrosivesecurity.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/korrosivesec/cetus-cearcher',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



import os
from enum import Enum

import typer
from rich.console import Console
from rich.syntax import Syntax
from rich.traceback import install

from . import search

# Initiate Rich traceback handlers
install()

console = Console()
error_console = Console(stderr=True, style="bold red")

app = typer.Typer(name="cetus", help="Cetus Cearcher")
app.add_typer(search.app, name="search", help="Search Cetus")


class index(str, Enum):
    dns = "dns"
    certstream = "certstream"


@app.command(help="Show example result data")
def example(
    index: index = typer.Argument(..., case_sensitive=False),
    raw: bool = typer.Option(
        False, "--raw", help="Print raw output instead of pretty printed"
    ),
):

    path = os.path.dirname(os.path.abspath(__file__))
    file = f"{path}/examples/{index.value}.json"
    formatted_example = Syntax.from_path(file)

    if not raw:
        console.print(formatted_example)
    else:
        with open(file) as raw_example:
            print(raw_example.read())
